@@ -98,7 +98,7 @@ __END__
 
 =head1 NAME
 
-Audio::Nama::Object - Class builder
+::Object - Class builder
 
 =head1 SYNOPSIS
 
@@ -115,5 +115,4 @@ Audio::Nama::Object - Class builder
 
   $object->set( bar => 2);
   
-  print "bar is " . $object->bar . "\n";
-
+  print "bar is " . $object->bar . "\n";
\ No newline at end of file
